@@ -111,6 +111,9 @@ class Data1D(object):
         """
         return self.y.size
 
+    def __str__(self):
+        return "<{0}>, {1} points".format(self.name, len(self))
+
     def __repr__(self):
         msk = self._mask
         if np.all(self._mask):
@@ -427,7 +430,7 @@ class Data1D(object):
                     nums = [float(tok) for tok in
                             re.split(r"\s|,", line)
                             if len(tok)]
-                    if len(nums) == 0:
+                    if len(nums) in [0, 1]:
                         # might be trailing newlines at the end of the file,
                         # just ignore those
                         continue
@@ -436,7 +439,7 @@ class Data1D(object):
                         numcols = len(nums)
                     elif len(nums) != numcols:
                         # if the number of columns changes there's an issue
-                            break
+                        break
                     x.append(nums[0])
                     y.append(nums[1])
                     if len(nums) > 2:
@@ -445,8 +448,9 @@ class Data1D(object):
                         x_err.append(nums[3])
                 except ValueError:
                     # you should drop into this if you can't parse tokens into
-                    # a series of floats
-                    break
+                    # a series of floats. But the text may be meta-data, so
+                    # try to carry on.
+                    continue
 
         x.reverse()
         y.reverse()
@@ -481,6 +485,39 @@ class Data1D(object):
             with open(self.filename) as f:
                 self.load(f)
 
+    def plot(self, fig=None):
+        """
+        Plot the dataset.
+
+        Requires matplotlib be installed.
+
+        Parameters
+        ----------
+        fig: Figure instance, optional
+            If `fig` is not supplied then a new figure is created. Otherwise
+            the graph is created on the current axes on the supplied figure.
+
+        Returns
+        -------
+        fig, ax : :class:`matplotlib.Figure`, :class:`matplotlib.Axes`
+            `matplotlib` figure and axes objects.
+
+        """
+        import matplotlib.pyplot as plt
+
+        if fig is None:
+            fig = plt.figure()
+            ax = fig.add_subplot(111)
+        else:
+            ax = fig.gca()
+
+        if self.y_err is not None:
+            ax.errorbar(self.x, self.y, self.y_err, label=self.name)
+        else:
+            ax.scatter(self.x, self.y, label=self.name)
+
+        return fig, ax
+
     def __add__(self, other):
         """
         Adds two datasets together. Splices the data and trims data in the
