@@ -49,7 +49,7 @@ class ReflectModel(object):
         Specifies the number of threads for parallel calculation. This
         option is only applicable if you are using the ``_creflect``
         module. The option is ignored if using the pure python calculator,
-        ``_reflect``. If `threads == 0` then all available processors are
+        ``_reflect``. If `threads == -1` then all available processors are
         used.
     quad_order: int, optional
         the order of the Gaussian quadrature polynomial for doing the
@@ -63,7 +63,7 @@ class ReflectModel(object):
 
     """
     def __init__(self, structure, scale=1, bkg=1e-7, name='', dq=5.,
-                 threads=0, quad_order=17):
+                 threads=-1, quad_order=17):
         self.name = name
         self._parameters = None
         self.threads = threads
@@ -180,7 +180,7 @@ class ReflectModel(object):
             # fallback to what this object was constructed with
             x_err = float(self.dq)
 
-        return reflectivity(x, self.structure.slabs[..., :4],
+        return reflectivity(x, self.structure.slabs()[..., :4],
                             scale=self.scale.value,
                             bkg=self.bkg.value,
                             dq=x_err,
@@ -667,7 +667,7 @@ class MixedReflectModel(object):
 
         # all reflectometry models need a scale factor and background. Set
         # them all to 1 by default.
-        pscales = Parameters('scale factors')
+        pscales = Parameters(name='scale factors')
 
         if scales is not None and len(structures) == len(scales):
             tscales = scales
@@ -690,6 +690,12 @@ class MixedReflectModel(object):
 
         self._structures = structures
 
+    def __repr__(self):
+        s = ("MixedReflectModel({_structures!r}, scales={_scales!r},"
+             " bkg={_bkg!r}, name={name!r}, dq={_dq!r}, threads={threads!r},"
+             " quad_order={quad_order!r})")
+        return s.format(**self.__dict__)
+
     def __call__(self, x, p=None, x_err=None):
         r"""
         Calculate the generative model
@@ -782,7 +788,7 @@ class MixedReflectModel(object):
 
         for scale, structure in zip(scales, self.structures):
             y += reflectivity(x,
-                              structure.slabs[..., :4],
+                              structure.slabs()[..., :4],
                               scale=scale,
                               dq=x_err,
                               threads=self.threads,
